@@ -1,19 +1,21 @@
 """
 Query models
 """
+from django.core.exceptions import ObjectDoesNotExist
 
-from mongoengine import errors as mongoengine_errors
-
-from core_explore_common_app.components.abstract_query.models import AbstractQuery
 from core_main_app.commons import exceptions
-
-
-# TODO: remove old queries from database
+from core_explore_common_app.components.abstract_query.models import AbstractQuery
 
 
 class Query(AbstractQuery):
     """Query class"""
 
+    class Meta:
+        """Meta"""
+
+        verbose_name = "Query"
+        verbose_name_plural = "Queries"
+
     @staticmethod
     def get_by_id(query_id):
         """Returns a query given its id
@@ -26,8 +28,8 @@ class Query(AbstractQuery):
         """
         try:
             return Query.objects.get(pk=str(query_id))
-        except mongoengine_errors.DoesNotExist as e:
-            raise exceptions.DoesNotExist(str(e))
+        except ObjectDoesNotExist as exception:
+            raise exceptions.DoesNotExist(str(exception))
         except Exception as ex:
             raise exceptions.ModelError(str(ex))
 
@@ -42,7 +44,7 @@ class Query(AbstractQuery):
 
         """
         for data_source in self.data_sources:
-            if data_source.name == name and data_source.url_query == url_query:
+            if data_source["name"] == name and data_source["url_query"] == url_query:
                 return data_source
         raise exceptions.DoesNotExist(
             "No data source found fot the given name and url."
