@@ -5,38 +5,36 @@ import math
 from abc import ABCMeta, abstractmethod
 from os.path import join
 
+from django.contrib.auth.decorators import login_required
 from django.http.response import HttpResponse, HttpResponseBadRequest
 from django.shortcuts import render as django_render
 from django.template import loader
 from django.urls import reverse
+from django.utils.decorators import method_decorator
 from django.utils.html import escape
 from django.views import View
 
-from core_explore_common_app.commons.exceptions import ExploreRequestError
+from core_main_app.commons.exceptions import DoesNotExist
+from core_main_app.utils.pagination.rest_framework_paginator.rest_framework_paginator import (
+    get_page_number,
+)
+from core_main_app.views.common.views import CommonView
 
+from core_explore_common_app import settings
+from core_explore_common_app.commons.exceptions import ExploreRequestError
 from core_explore_common_app.components.abstract_persistent_query import (
     api as abstract_persistent_query_api,
 )
 from core_explore_common_app.components.abstract_persistent_query.models import (
     AbstractPersistentQuery,
 )
-from django.utils.decorators import method_decorator
-from django.contrib.auth.decorators import login_required
-
-from core_main_app.views.common.views import CommonView
 from core_explore_common_app.components.query import api as query_api
 from core_explore_common_app.constants import LOCAL_QUERY_NAME
-from core_explore_common_app import settings
-
 from core_explore_common_app.utils.query.query import (
     send as send_query,
     add_local_data_source,
     get_local_query_absolute_url,
 )
-from core_main_app.commons.exceptions import DoesNotExist
-from core_main_app.utils.pagination.rest_framework_paginator.rest_framework_paginator import (
-    get_page_number,
-)
 
 
 def get_local_data_source(request):
@@ -67,8 +65,8 @@ def get_local_data_source(request):
             local_query_url = get_local_query_absolute_url(request)
             for data_source in query.data_sources:
                 if (
-                    data_source.name == LOCAL_QUERY_NAME
-                    and data_source.url_query == local_query_url
+                    data_source["name"] == LOCAL_QUERY_NAME
+                    and data_source["url_query"] == local_query_url
                 ):
                     context_params["selected"] = True
 
@@ -80,9 +78,12 @@ def get_local_data_source(request):
                 "core_explore_common_app/user/selector/local_content.html",
                 context=context,
             )
-        else:
-            return HttpResponseBadRequest("Expected query_id parameter is missing.")
-    except Exception as e:
+
+        return HttpResponseBadRequest("Expected query_id parameter is missing.")
+
+    except DoesNotExist:
+        return HttpResponseBadRequest("The query does not exist.")
+    except Exception:
         return HttpResponseBadRequest(
             "An unexpected error occurred while getting local data source selector."
         )
@@ -116,8 +117,11 @@ def update_local_data_source(request):
             query_api.remove_data_source(query, data_source, request.user)
 
         return HttpResponse()
-    except Exception as e:
-        return HttpResponseBadRequest(escape(str(e)))
+
+    except DoesNotExist:
+        return HttpResponseBadRequest("The query does not exist.")
+    except Exception as exception:
+        return HttpResponseBadRequest(escape(str(exception)))
 
 
 def get_data_sources_html(request):
@@ -168,8 +172,10 @@ def get_data_sources_html(request):
 
         response_dict = {"results": html_results_holders}
         return HttpResponse(json.dumps(response_dict), content_type="application/json")
-    except Exception as e:
-        return HttpResponseBadRequest(escape(str(e)))
+    except DoesNotExist:
+        return HttpResponseBadRequest("The query does not exist.")
+    except Exception as exception:
+        return HttpResponseBadRequest(escape(str(exception)))
 
 
 def get_data_source_results(request, query_id, data_source_index, page=1):
@@ -241,13 +247,16 @@ def get_data_source_results(request, query_id, data_source_index, page=1):
         # set response with html results
         response_dict = {"results": results_html, "nb_results": results["count"]}
         return HttpResponse(json.dumps(response_dict), content_type="application/json")
+
+    except DoesNotExist:
+        return HttpResponseBadRequest("The query does not exist.")
     except ExploreRequestError as ex:
         return HttpResponseBadRequest(
             "An error occurred while sending the query: " + escape(str(ex)),
         )
-    except Exception as e:
+    except Exception as exception:
         return HttpResponseBadRequest(
-            "An unexpected error occurred: " + escape(str(e)),
+            "An unexpected error occurred: " + escape(str(exception)),
         )
 
 
@@ -269,14 +278,13 @@ class CreatePersistentQueryUrlView(View, metaclass=ABCMeta):
             query_id = request.POST.get("queryId", None)
 
             # get the matching query
-            try:
-                query = query_api.get_by_id(query_id, request.user)
-            except DoesNotExist:
-                return HttpResponseBadRequest("The query does not exist anymore.")
+            query = query_api.get_by_id(query_id, request.user)
 
             # create the persistent query
             persistent_query = abstract_persistent_query_api.upsert(
-                self._create_persistent_query(query), request.user
+                self._create_persistent_query(query),
+                query.templates.all(),
+                request.user,
             )
             # reverse to the url
             url_reversed = request.build_absolute_uri(reverse(self.view_to_reverse))
@@ -285,9 +293,11 @@ class CreatePersistentQueryUrlView(View, metaclass=ABCMeta):
                 json.dumps({"url": url_reversed + "?id=" + str(persistent_query.id)}),
                 content_type="application/javascript",
             )
-        except Exception as e:
+        except DoesNotExist:
+            return HttpResponseBadRequest("The query does not exist anymore.")
+        except Exception as exception:
             return HttpResponseBadRequest(
-                escape(str(e)), content_type="application/javascript"
+                escape(str(exception)), content_type="application/javascript"
             )
 
     @staticmethod
@@ -315,6 +325,14 @@ class ContentPersistentQueryView(CommonView):
     )
 
     def get(self, request, *args, **kwargs):
+        """Gets persistent query
+
+        Args:
+            request:
+
+        Returns:
+
+        """
 
         try:
             # get persistent query id
@@ -336,7 +354,9 @@ class ContentPersistentQueryView(CommonView):
             persistent_query = abstract_persistent_query_api.get_by_id(
                 persistent_query_class, persistent_query_id, request.user
             )
-        except:
+        except DoesNotExist:
+            return HttpResponseBadRequest("The query does not exist.")
+        except Exception:
             return HttpResponseBadRequest("Something wrong happened.")
 
         # create context
